package com.xunmei.system.mapper;

import java.util.List;

import com.xunmei.system.domain.SysWorkTimeMonth;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-14
 */
public interface SysWorkTimeMonthMapper extends BaseMapper<SysWorkTimeMonth> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysWorkTimeMonth selectSysWorkTimeMonthById(String id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysWorkTimeMonth 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysWorkTimeMonth> selectSysWorkTimeMonthList(SysWorkTimeMonth sysWorkTimeMonth);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysWorkTimeMonth 【请填写功能名称】
     * @return 结果
     */
     int insertSysWorkTimeMonth(SysWorkTimeMonth sysWorkTimeMonth);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysWorkTimeMonth 【请填写功能名称】
     * @return 结果
     */
     int updateSysWorkTimeMonth(SysWorkTimeMonth sysWorkTimeMonth);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysWorkTimeMonthById(String id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysWorkTimeMonthByIds(String[] ids);
}
